<?php
/*
Plugin Name: Nudgify
Description: Install Nudgify on your WordPress website in less then 10 seconds. Integrate unique tracking code of Nudgify into every page of your website in one click.
Author: Nudgify
Version: 1.0.4
Author URI: https://nudgify.com
License: GPLv2
Plugin URI: https://nudgify.com/
*/

defined('ABSPATH') or die('Restricted access!');

define('NUDGIFY_PLUGIN_SLUG', 'nudgify');
define('NUDGIFY_PLUGIN_URL', plugin_dir_url(__FILE__));
define('NUDGIFY_PLUGIN_DIR', str_replace('\\', '/', dirname(__FILE__)));

if (!class_exists('Nudgify')) {
    require_once(NUDGIFY_PLUGIN_DIR . '/settings.php');

    class Nudgify
    {
        public function __construct()
        {
            add_action('admin_init', [$this, 'init_settings']);
            add_action('admin_menu', [$this, 'init_menu']);
            add_action('wp_head', [$this, 'print_pixel']);
        }

        public function init_settings()
        {
            register_setting('nudgify-site-key', 'nudgify-site-key', [$this, 'sanitise_nudgify_site_key']);
        }

        public function init_menu()
        {
            add_menu_page(
                'Nudgify',
                'Nudgify',
                'manage_options',
                NUDGIFY_PLUGIN_SLUG,
                [$this, 'nudgify_options_form'],
                NUDGIFY_PLUGIN_URL . 'icon.png'
            );
        }

        public function print_pixel()
        {
            $uuid = get_option('nudgify-site-key', '');

            if (!$this->is_valid_site_key($uuid)) {
                return;
            }

            $uuid = json_encode($uuid);
            $url = json_encode(NUDGIFY_PIXEL_BASE . '/pixel.js');

            echo implode("\n", array(
                '<script>',
                '   (function(){',
                "       window.nudgify={uuid:{$uuid}};",
                '       var d=document,s=d.createElement("script");',
                "       s.src={$url};",
                '       s.async=1;',
                '       s.charset="utf-8";',
                '       d.getElementsByTagName("head")[0].appendChild(s)',
                '   })()',
                '</script>',
            ));
        }

        public function sanitise_nudgify_site_key($siteKey)
        {
            $siteKey = trim($siteKey);

            if (!$this->is_valid_site_key($siteKey) || empty($siteKey)) {
                add_settings_error(
                    'nudgify-site-key',
                    esc_attr('settings_updated'),
                    'This field does not a contain valid site key',
                    'error'
                );

                return '';
            }

            return $siteKey;
        }

        public function nudgify_options_form()
        {
            require_once(NUDGIFY_PLUGIN_DIR . '/inc/options.php');
        }

        private function is_valid_site_key($siteKey)
        {
            $UUIDv4 = '/^[0-9A-F]{8}-[0-9A-F]{4}-4[0-9A-F]{3}-[89AB][0-9A-F]{3}-[0-9A-F]{12}$/Di';
            return preg_match($UUIDv4, $siteKey);
        }
    }

    $nudgify = new Nudgify();
}
